NAME
AmberDB::Tools - Database maintenance, reindexing, and utility helper module
SYNOPSIS
use AmberDB::Tools;
my $tools = AmberDB::Tools->new($dbp);
# Rebuild all indexes for a table
$tools->set_index($table_id);
# Rebuild search index
$tools->set_search($table_id);
DESCRIPTION
AmberDB::Tools provides maintenance functions for rebuilding indexes, creating full-text search keys, managing facet forward indexes, and generating table backups.
METHODS
new($dbp, [%options])
Constructor for AmberDB::Tools. Accepts an AmberDB instance handle.
set_index($table_id, [@records])
Rebuilds all indexes (readall, search, match, facet, sort) for specified table.
set_readall($table_id, @ids)
Rebuilds primary readall key index.
set_search($table_id, [@records])
Rebuilds full-text search index.
set_fields($table_id, [@records])
Rebuilds field matching index.
set_filters($table_id, [@records])
Rebuilds facet forward filter index.
set_sort($table_id, [@records])
Rebuilds binary sort index.
AUTHOR
Maruf Cetin <marufcetin@gmail.com>
LICENSE AND COPYRIGHT
Copyright (C) 2018-2026 Maruf Cetin.
This library is free software; you can redistribute it and/or modify it under the terms of the Artistic License 2.0.